@@ -7,10 +7,9 @@ use Config;
 use FFI::Platypus;
 use FFI::Platypus::Memory qw( malloc free );
 use Carp qw( croak carp );
-use File::ShareDir ();
 
 # ABSTRACT: Tiny C Compiler for FFI
-our $VERSION = '0.22'; # VERSION
+our $VERSION = '0.23'; # VERSION
 
 
 sub _dlext ()
@@ -20,17 +19,10 @@ sub _dlext ()
 
 our $ffi = FFI::Platypus->new;
 $ffi->lib(
-  $ENV{FFI_TINYCC_LIBTCC_SO} || (eval { File::ShareDir::dist_dir('FFI-TinyCC') } ? File::ShareDir::dist_file('FFI-TinyCC', "libtcc." . _dlext) : do {
-    require Path::Class::File;
-    Path::Class::File
-      ->new($INC{'FFI/TinyCC.pm'})
-      ->dir
-      ->parent
-      ->parent
-      ->file('share', 'libtcc.' . _dlext)
-      ->stringify
-  }
-));
+  do { $_ = __FILE__; s{TinyCC.pm}{.TinyCC.devshare}; -e $_ } 
+    ? ( 'share/libtcc.' . _dlext ) 
+    : do { require File::ShareDir; File::ShareDir::dist_file('FFI-TinyCC', 'libtcc.' . _dlext) },
+);
 
 $ffi->custom_type( tcc_t => {
   perl_to_native => sub {
@@ -373,12 +365,12 @@ FFI::TinyCC - Tiny C Compiler for FFI
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 SYNOPSIS
 
  use FFI::TinyCC;
- use FFI::Platypus::Declare qw( int );
+ use FFI::Platypus;
  
  my $tcc = FFI::TinyCC->new;
  
@@ -391,14 +383,15 @@ version 0.22
  });
  
  my $address = $tcc->get_symbol('find_square');
- attach [$address => 'find_square'] => [int] => int;
+ my $ffi = FFI::Platypus->new;
+ $ffi->attach([$address => 'find_square'] => ['int'] => 'int');
  
  print find_square(4), "\n"; # prints 16
 
 For code that requires system headers:
 
  use FFI::TinyCC;
- use FFI::Platypus::Declare qw( void );
+ use FFI::Platypus;
  
  my $tcc = FFI::TinyCC->new;
  
@@ -416,7 +409,8 @@ For code that requires system headers:
  });
  
  my $address = $tcc->get_symbol('print_hello');
- attach [$address => 'print_hello'] => [] => void;
+ my $ffi = FFI::Platypus->new;
+ $ffi->attach([$address => 'print_hello'] => [] => 'void');
  print_hello();
 
 =head1 DESCRIPTION
@@ -479,12 +473,13 @@ example below for how to use this to call Perl from Tiny C code.
 It will accept a L<FFI::Raw::Callback> at a performance penalty. If 
 possible pass in the pointer to the C entry point instead.
 
-If you are using L<FFI::Platypus> you can use L<FFI::Platypus#cast> or 
-L<FFI::Platypus::Declare#cast> to get a pointer to a closure:
+If you are using L<FFI::Platypus> you can use L<FFI::Platypus#cast>
+to get a pointer to a closure:
 
- use FFI::Platypus::Declare;
- my $clousre = closure { return $_[0]+1 };
- my $pointer = cast '(int)->int' => 'opaque', $closure;
+ use FFI::Platypus;
+ my $ffi = FFI::Platypus;
+ my $closure = $ffi->closure(sub { return $_[0]+1 });
+ my $pointer = $ffi->cast('(int)->int' => 'opaque', $closure);
  
  $tcc->add_symbol('foo' => $pointer);
 
@@ -576,8 +571,7 @@ Add the given directory to the search path used to find libraries.
 
 Return symbol address or undef if not found.  This can be passed into 
 the L<FFI::Platypus#function> method, L<FFI::Platypus#attach> method, 
-L<FFI::Platypus::Declare#function> function or similar interface that 
-takes a pointer to a C function.
+or similar interface that takes a pointer to a C function.
 
 =head3 output_file
 
@@ -611,8 +605,9 @@ Do this:
 
 Or better yet, use L<FFI::Platypus> instead:
 
- use FFI::Platypus::Declare;
- attach [$tcc->get_symbol($name) => 'function'] => [] => 'void';
+ use FFI::Platypus;
+ my $ffi = FFI::Platypus->new;
+ $ffi->attach([$tcc->get_symbol($name) => 'function'] => [] => 'void');
  function();
 
 =head1 EXAMPLES
@@ -638,10 +633,11 @@ Or better yet, use L<FFI::Platypus> instead:
 =head2 Calling Perl from Tiny C code
 
  use FFI::TinyCC;
- use FFI::Platypus::Declare qw( opaque );
+ use FFI::Platypus;
  
- my $say = closure { print $_[0], "\n" };
- my $ptr = cast '(string)->void' => opaque => $say;
+ my $ffi = FFI::Platypus->new;
+ my $say = $ffi->closure(sub { print $_[0], "\n" });
+ my $ptr = $ffi->cast('(string)->void' => 'opaque' => $say);
  
  my $tcc = FFI::TinyCC->new;
  $tcc->add_symbol(say => $ptr);
@@ -667,7 +663,7 @@ Or better yet, use L<FFI::Platypus> instead:
 =head2 Attaching as a FFI::Platypus function from a Tiny C function
 
  use FFI::TinyCC;
- use FFI::Platypus::Declare qw( int );
+ use FFI::Platypus;
  
  my $tcc = FFI::TinyCC->new;
  
@@ -684,7 +680,8 @@ Or better yet, use L<FFI::Platypus> instead:
  
  my $address = $tcc->get_symbol('calculate_square');
  
- attach [$address => 'square'] => [int] => int;
+ my $ffi = FFI::Platypus->new;
+ $ffi->attach([$address => 'square'] => ['int'] => 'int');
  
  print square($value), "\n";
 
@@ -725,9 +722,9 @@ from L<Inline::C::Parser::RegExp>
 
 The license details for the parser are:
 
-Copyright 2002 Brian Ingerson
-Copyright 2008, 2010-2012 Sisyphus
-Copyright 2013 Steffen Muellero
+ Copyright 2002 Brian Ingerson
+ Copyright 2008, 2010-2012 Sisyphus
+ Copyright 2013 Steffen Muellero
 
 This program is free software; you can redistribute it and/or modify it 
 under the same terms as Perl itself.
